@@ -26,8 +26,8 @@ from django.contrib.admin.views.decorators import staff_member_required
 from Iuppiter.dispatch import ThreadPool
 from Iuppiter.extension.views import jsonpCallback
 
-from Theophrastus.models import MailingList, Newsletter, 
-                                ContactMailingStatus, Contact
+from Theophrastus.models import (MailingList, Newsletter, 
+                                ContactMailingStatus, Contact)
 from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.newsletter_extension.models import Header, Footer
 
